<?php
/**
 * SectionHeader widget.
 * Plugin Name: Section Header
 * Description: Separate your board content according to Sections. A Section header can be linked to a specific page.
 * Version: 1.0
 * Author: Infomaker Scandinavia AB
 * Author URI: http://infomaker.se
 */

namespace EwWidgets;

use EwTools\Admin\Widget;
use EwTools\Handler\OpenContent;
use EwTools\Handler\OpenContentQueryBuilder;
use EwTools\Models\Page;
use EwTools\Models\Section;
use EwTools\Support\Str;
use EwTools\Handler\Pages;

/**
 * SectionHeader
 *
 * @link    http://infomaker.se
 * @package EwTools\Widgets
 * @since   EwTools\Widgets\SectionHeader 0.1
 */
class SectionHeader extends Widget {
    
    /**
     * Twig-template to use
     *
     * @var string
     */
    protected $template_path = '@tools/widgets/section-header';
    
    /**
     * Widget fields
     * Contains fields to manage the headline, a section to bind it to
     * and a way to link the headline to a page or custom link.
     *
     * @var array
     */
    protected $fields = [
        'headline' => '',
        'section'  => '',
        'page'     => '',
        'link'     => ''
    ];
    
    /**
     * SectionHeader constructor.
     *
     * @since 0.1
     */
    public function __construct() {
        $this->setWidgetData( __FILE__ );
        parent::__construct( 'ew-section-header' );
    }
    
    /**
     * Fires when rendering the widget form
     *
     * @param array $view_data
     *
     * @since 0.1
     * @return void
     */
    protected function edit( $view_data ) {
        $view_data = array_replace_recursive( $view_data, [
            'sections' => Section::toSelect( $view_data[ 'section' ][ 'value' ] ),
            'pages'    => Pages::getSelectData(),
        ] );
        $this->view( 'form', $view_data );
    }
    
    /**
     * Fires when rendering widget
     *
     * @param array $view_data
     *
     * @since 0.1
     * @return void
     */
    protected function show( $view_data ) {
        $page = Str::notEmpty( $view_data[ 'page' ] ) ? Page::getPermalink( $view_data[ 'page' ] ) : '';
        
        $view_data = array_replace_recursive( $view_data, [
            'section_class' => Section::getClassBySlug( $view_data[ 'section' ] ),
            'headline_link' => Str::notEmpty( $view_data[ 'link' ] ) ? $view_data[ 'link' ] : $page
        ] );
        
        $this->view( 'widget', $view_data );
    }
}

SectionHeader::register();